package com.flyer.foster.controller.app;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.flyer.foster.dto.app.AppFosterRecordAddDTO;
import com.flyer.foster.dto.TreeUpdateDTO;
import com.flyer.foster.dto.app.AppFosterRecordQueryDTO;
import com.flyer.foster.entity.FosterRecord;
import com.flyer.foster.entity.Tree;
import com.flyer.foster.pojo.StpAppUtil;
import com.flyer.foster.service.IFosterRecordService;
import com.flyer.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 领养记录（小程序）
 *
 * @author flyer
 * @since 2024-05-09
 */
@RestController
@RequestMapping("/app/foster-record")
public class AppFosterRecordController {

    @Autowired
    private IFosterRecordService iFosterRecordService;

    /**
     * 根据果园id查询领养记录
     *
     * @return
     */
    @GetMapping("/list/{gardenId}")
    public R list(@PathVariable Integer gardenId) {
        String appUserId = StpAppUtil.getLoginId().toString();
        List<FosterRecord> res = iFosterRecordService.lambdaQuery().
                eq(FosterRecord::getAppUserId, appUserId)
                .eq(FosterRecord::getGardenId, gardenId)
                .list();
        return R.ok().result(res);
    }

    /**
     * 修改树
     */
    @PutMapping("")
    public R update(@RequestBody FosterRecord updateDTO) {
        String appUserId = StpAppUtil.getLoginId().toString();
        return R.ok().result(
                iFosterRecordService.lambdaUpdate()
                        .set(FosterRecord::getName, updateDTO.getName())
                        .eq(FosterRecord::getAppUserId, appUserId)
                        .eq(FosterRecord::getGardenId, updateDTO.getGardenId())
                        .update());
    }

    /**
     * 领养记录-分页
     *
     * @param current
     * @param size
     * @param queryDTO
     * @return
     */
    @GetMapping("/list/{current}/{size}")
    public R getPageList(@PathVariable Integer current, @PathVariable Integer size, AppFosterRecordQueryDTO queryDTO) {
        return R.ok().result(iFosterRecordService.getPageList(new Page<>(current, size), queryDTO));
    }

    /**
     * 确认领养
     *
     * @return
     */
    @PostMapping("")
    public R addFosterRecord(@Valid @RequestBody AppFosterRecordAddDTO addDTO) {
        return R.ok().result(iFosterRecordService.addFosterRecord(addDTO));
    }

    /**
     * 认养天数
     *
     * @return
     */
    @GetMapping("/foster-days")
    public R getFosterDays(AppFosterRecordQueryDTO queryDTO) {
        return R.ok().result(iFosterRecordService.getFosterDays(queryDTO));
    }
}
